LogsNotificationsConfig class
Configuration for the logsSubscribe RPC subscription method.
Subscribe to receive notifications containing the logs of transactions.
Constructors
- LogsNotificationsConfig({Commitment? commitment})
-
Creates a new LogsNotificationsConfig.
const
Properties
- commitment → Commitment?
-
Get notified on logs from new transactions that have reached this
level of commitment.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this config to a JSON-RPC params map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited